@@ -576,6 +576,7 @@ EvdevReadInput(InputInfoPtr pInfo)
         {
             if (errno == ENODEV) /* May happen after resume */
             {
+                EvdevMBEmuFinalize(pInfo);
                 xf86RemoveEnabledDevice(pInfo);
                 close(pInfo->fd);
                 pInfo->fd = -1;
@@ -1544,8 +1545,7 @@ EvdevProbe(InputInfoPtr pInfo)
         int mapping = 0;
         if (TestBit(i, pEvdev->key_bitmask))
         {
-            mapping =
-                pEvdev->btnmap[EvdevUtilButtonEventToButtonNumber(pEvdev, i)];
+            mapping = EvdevUtilButtonEventToButtonNumber(pEvdev, i);
             if (mapping > num_buttons)
                 num_buttons = mapping;
         }
